:mod:`art.estimators.speech_recognition`
========================================
.. automodule:: art.estimators.speech_recognition

Mixin Base Class Speech Recognizer
----------------------------------
.. autoclass:: SpeechRecognizerMixin
   :members:
   :special-members: __init__
   :inherited-members:

Speech Recognizer Deep Speech
-----------------------------
.. autoclass:: PyTorchDeepSpeech
   :members:
   :special-members: __init__
   :inherited-members:
